function g1 = dynamic_g1(T, y, x, params, steady_state, it_, T_flag)
% function g1 = dynamic_g1(T, y, x, params, steady_state, it_, T_flag)
%
% File created by Dynare Preprocessor from .mod file
%
% Inputs:
%   T             [#temp variables by 1]     double   vector of temporary terms to be filled by function
%   y             [#dynamic variables by 1]  double   vector of endogenous variables in the order stored
%                                                     in M_.lead_lag_incidence; see the Manual
%   x             [nperiods by M_.exo_nbr]   double   matrix of exogenous variables (in declaration order)
%                                                     for all simulation periods
%   steady_state  [M_.endo_nbr by 1]         double   vector of steady state values
%   params        [M_.param_nbr by 1]        double   vector of parameter values in declaration order
%   it_           scalar                     double   time period for exogenous variables for which
%                                                     to evaluate the model
%   T_flag        boolean                    boolean  flag saying whether or not to calculate temporary terms
%
% Output:
%   g1
%

if T_flag
    T = Simple_Eq_simulations_strong.dynamic_g1_tt(T, y, x, params, steady_state, it_);
end
g1 = zeros(10, 21);
g1(1,1)=(-1);
g1(1,9)=1;
g1(1,2)=params(2);
g1(1,10)=(-1);
g1(1,3)=(-(params(2)-1));
g1(1,5)=params(3)*(-params(2));
g1(1,13)=params(3);
g1(1,14)=(-1);
g1(2,9)=(-1);
g1(2,11)=1;
g1(2,15)=(-1);
g1(3,10)=1;
g1(3,3)=(-(1+1-params(1)));
g1(3,12)=(-params(1));
g1(3,8)=1-params(1);
g1(4,3)=(-(1-params(4)));
g1(4,4)=(-params(4));
g1(4,12)=1;
g1(4,8)=1-params(4);
g1(5,6)=(-params(5));
g1(5,14)=1;
g1(5,19)=(-1);
g1(6,7)=(-params(6));
g1(6,15)=1;
g1(6,20)=(-1);
g1(7,5)=(-params(7));
g1(7,13)=1;
g1(7,21)=1;
g1(8,3)=1;
g1(8,11)=(-1);
g1(8,16)=1;
g1(9,1)=1;
g1(9,9)=(-1);
g1(9,17)=1;
g1(10,3)=(-1);
g1(10,18)=1;

end
